From 55f1f56fec7b6fcecb968d0e13c2a3a250e8da65 Mon Sep 17 00:00:00 2001
From: Benoit Marty <benoit@matrix.org>
Date: Thu, 29 Apr 2021 12:14:55 +0200
Subject: [PATCH] `master` branch has been renamed to `main` Also in project
 vector-im/jitsi_libre_maven

---
 CHANGES.md          | 8 ++++++++
 build.gradle        | 2 +-
 vector/build.gradle | 6 +++---
 3 files changed, 12 insertions(+), 4 deletions(-)

diff --git a/CHANGES.md b/CHANGES.md
index 8a193e762c..44eadc423d 100644
--- a/CHANGES.md
+++ b/CHANGES.md
@@ -29,6 +29,14 @@ Test:
 
 Other changes:
  - New store descriptions
+ - `master` branch has been renamed to `main`. To apply change to your dev environment, run:
+```sh
+git branch -m master main
+git fetch origin
+git branch -u origin/main main
+# And optionally
+git remote prune origin
+```
 
 Changes in Element 1.1.6 (2021-04-16)
 ===================================================
diff --git a/build.gradle b/build.gradle
index 537a78992d..25734e3b09 100644
--- a/build.gradle
+++ b/build.gradle
@@ -59,7 +59,7 @@ allprojects {
         maven { url 'https://oss.sonatype.org/content/repositories/snapshots/' }
         // Jitsi repo
         maven {
-            url "https://github.com/vector-im/jitsi_libre_maven/raw/master/android-sdk-3.1.0"
+            url "https://github.com/vector-im/jitsi_libre_maven/raw/main/android-sdk-3.1.0"
             // Note: to test Jitsi release you can use a local file like this:
             // url "file:///Users/bmarty/workspaces/jitsi_libre_maven/android-sdk-3.1.0"
         }
diff --git a/vector/build.gradle b/vector/build.gradle
index 7569e0c32f..3ecdcea524 100644
--- a/vector/build.gradle
+++ b/vector/build.gradle
@@ -64,9 +64,9 @@ static def gitBranchName() {
     }
 }
 
 // For Google Play build, build on any other branch than master will have a "-dev" suffix
 static def getGplayVersionSuffix() {
-    if (gitBranchName() == "master") {
+    if (gitBranchName() == "main") {
         return ""
     } else {
         return "-dev"
@@ -119,7 +119,7 @@ android {
         renderscriptSupportModeEnabled true
 
         // `develop` branch will have version code from timestamp, to ensure each build from CI has a incremented versionCode.
         // Other branches (master, features, etc.) will have version code based on application version.
         versionCode project.getVersionCode()
 
         // Required for sonar analysis
@@ -64,9 +64,9 @@ static def gitBranchName() {
 }
 
-// For Google Play build, build on any other branch than master will have a "-dev" suffix
+// For Google Play build, build on any other branch than main will have a "-dev" suffix
 static def getGplayVersionSuffix() {
@@ -119,7 +119,7 @@ android {
 
         // `develop` branch will have version code from timestamp, to ensure each build from CI has a incremented versionCode.
-        // Other branches (master, features, etc.) will have version code based on application version.
+        // Other branches (main, features, etc.) will have version code based on application version.
         versionCode project.getVersionCode()
 